@@ -128,6 +128,8 @@
 #' algorithm that includes accounts for any overdispersion by adding a
 #' geological (co)variance term.
 #'
+#' @param title add a title to the plot?
+#' 
 #' @param sigdig number of significant digits for the
 #'     concordia/discordia age
 #' 
@@ -275,7 +277,7 @@ concordia <- function(x=NULL,tlim=NULL,type=1,
                       show.numbers=FALSE,levels=NULL,clabel="",
                       ellipse.fill=c("#00FF0080","#FF000080"),
                       ellipse.stroke='black',concordia.col='darksalmon',
-                      exterr=FALSE,show.age=0,oerr=3,
+                      exterr=FALSE,show.age=0,title=TRUE,oerr=3,
                       sigdig=2,common.Pb=0,ticks=5,anchor=0,
                       cutoff.disc=discfilter(),hide=NULL,
                       omit=NULL,omit.fill=NA,omit.stroke='grey',...){
@@ -284,10 +286,10 @@ concordia <- function(x=NULL,tlim=NULL,type=1,
                      ellipse.fill=ellipse.fill,
                      ellipse.stroke=ellipse.stroke,
                      concordia.col=concordia.col,exterr=exterr,
-                     show.age=show.age,oerr=oerr,sigdig=sigdig,
-                     common.Pb=common.Pb,ticks=ticks,anchor=anchor,
-                     cutoff.disc=cutoff.disc,hide=hide,
-                     omit=omit,omit.fill=omit.fill,
+                     show.age=show.age,title=title,oerr=oerr,
+                     sigdig=sigdig,common.Pb=common.Pb,ticks=ticks,
+                     anchor=anchor,cutoff.disc=cutoff.disc,
+                     hide=hide,omit=omit,omit.fill=omit.fill,
                      omit.stroke=omit.stroke,...)
 }
 
@@ -297,11 +299,11 @@ concordia_helper <- function(x=NULL,tlim=NULL,type=1,
                              show.numbers=FALSE,levels=NULL,clabel="",
                              ellipse.fill=c("#00FF0080","#FF000080"),
                              ellipse.stroke='black',concordia.col='darksalmon',
-                             exterr=FALSE,show.age=0,oerr=3,y0option=1,
-                             sigdig=2,common.Pb=0,ticks=5,anchor=0,
-                             cutoff.disc=discfilter(),hide=NULL,
-                             omit=NULL,omit.fill=NA,omit.stroke='grey',
-                             box=TRUE,...){
+                             exterr=FALSE,show.age=0,title=TRUE,
+                             oerr=3,y0option=1,sigdig=2,common.Pb=0,
+                             ticks=5,anchor=0,cutoff.disc=discfilter(),
+                             hide=NULL,omit=NULL,omit.fill=NA,
+                             omit.stroke='grey',box=TRUE,...){
     if (is.null(x)){
         emptyconcordia(tlim=tlim,oerr=oerr,type=type,exterr=exterr,
                        concordia.col=concordia.col,ticks=ticks,...)
@@ -338,10 +340,12 @@ concordia_helper <- function(x=NULL,tlim=NULL,type=1,
     lims <- prepare_concordia_line(x=X2plot,tlim=tlim,type=type,...)
     if (show.age>1){
         discordia_line(fit,wetherill=(type==1),d=X2plot$d,oerr=oerr)
-        dispunits <- getDispUnits_UPb(x=x,joint=TRUE,anchor=anchor)
-        graphics::title(discordia_title(fit,wetherill=(type==1),
-                                        y0option=y0option,sigdig=sigdig,
-                                        oerr=oerr,dispunits=dispunits,...))
+        if (title){
+            dispunits <- getDispUnits_UPb(x=x,joint=TRUE,anchor=anchor)
+            graphics::title(discordia_title(fit,wetherill=(type==1),
+                                            y0option=y0option,sigdig=sigdig,
+                                            oerr=oerr,dispunits=dispunits,...))
+        }
     }
     plotConcordiaLine(X2plot,lims=lims,type=type,col=concordia.col,
                       oerr=oerr,exterr=exterr,ticks=ticks,box=box)
@@ -361,7 +365,9 @@ concordia_helper <- function(x=NULL,tlim=NULL,type=1,
     if (show.age==1){
         ell <- ellipse(fit$x[1],fit$x[2],fit$ccov)
         graphics::polygon(ell,col='white')
-        graphics::title(concordia_title(fit,sigdig=sigdig,oerr=oerr))
+        if (title){
+            graphics::title(concordia_title(fit,sigdig=sigdig,oerr=oerr))
+        }
     }
     colourbar(z=levels[calcit],fill=ellipse.fill,
               stroke=ellipse.stroke,clabel=clabel)
@@ -374,7 +380,7 @@ plotConcordiaLine <- function(x,lims,type=1,col='darksalmon',
     if (length(ticks)<2) ticks <- prettier(lims$t,type=type,n=ticks)
     m <- min(lims$t[1],ticks[1])
     M <- max(lims$t[2],utils::tail(ticks,1))
-    nn <- 30 # number of segments into which the concordia line is divided
+    nn <- 100 # number of segments into which the concordia line is divided
     tt <- cseq(0.9*m,M,type=type,n=nn)
     conc <- matrix(0,nn,2)
     colnames(conc) <- c('x','y')
