@@ -85,6 +85,10 @@
 #' @param plot logical. Only relevant for datasets with measured
 #'     disequilibrium. If \code{TRUE}, plots the posterior
 #'     distribution of the age and initial activity ratios.
+#' 
+#' @param nsteps resolution of the posterior distributions for
+#'     Bayesian credible intervals of disequilibrium-corrected U-Pb
+#'     isochrons
 #'
 #' @param ... optional arguments
 #' 
@@ -131,7 +135,7 @@ ludwig <- function(x,...){ UseMethod("ludwig",x) }
 #' @rdname ludwig
 #' @export
 ludwig <- function(x,model=1,anchor=0,exterr=FALSE,
-                   type='joint',plot=FALSE,...){
+                   type='joint',plot=FALSE,nsteps=NULL,...){
     type <- checkIsochronType(x,type)
     X <- x
     X$d <- mediand(x$d)
@@ -142,7 +146,7 @@ ludwig <- function(x,model=1,anchor=0,exterr=FALSE,
     fit$cov <- inverthess(fit$hessian)
     if (measured_disequilibrium(X$d) & type%in%c('joint',0,1,3)){
         fit$posterior <- bayeslud(fit,x=X,anchor=anchor,type=type,
-                                  model=model,plot=plot,...)
+                                  model=model,plot=plot,nsteps=nsteps)
     }
     efit <- exponentiate(fit)
     afit <- anchormerge(efit,X,anchor=anchor,type=type)
